@@ -5,16 +5,16 @@ from functools import wraps
 
 import numpy as _np
 import torch
-from torch import arange, arccos, arccosh, arcsin, arctanh, argmin
+from torch import angle, arange, arccos, arccosh, arcsin, arctanh, argmin
 from torch import atan2 as arctan2  # NOQA
 from torch import bool as t_bool
 from torch import broadcast_tensors as broadcast_arrays
 from torch import (
     ceil,
     clip,
-    complex32,
     complex64,
     complex128,
+    conj,
     cos,
     cosh,
     cross,
@@ -30,11 +30,20 @@ from torch import (
     floor,
 )
 from torch import fmod as mod
-from torch import greater, hstack, imag, int32, int64, isnan, less, log, logical_or
+from torch import (
+    greater,
+    hstack,
+    imag,
+    int32,
+    int64,
+    isnan,
+    kron,
+    less,
+    log,
+    logical_or,
+)
 from torch import max as amax
-from torch import mean, meshgrid
-from torch import min as amin
-from torch import nonzero, ones, ones_like, outer, polygamma
+from torch import mean, meshgrid, nonzero, ones, ones_like, outer, polygamma
 from torch import pow as power
 from torch import real
 from torch import repeat_interleave as repeat
@@ -210,7 +219,15 @@ def concatenate(seq, axis=0, out=None):
 
 
 def _get_largest_dtype(seq):
-    dtype_dict = {0: t_bool, 1: uint8, 2: int32, 3: int64, 4: float32, 5: float64}
+    dtype_dict = {
+        0: t_bool,
+        1: uint8,
+        2: int32,
+        3: int64,
+        4: float32,
+        5: float64,
+        6: complex128,
+    }
     reverse_dict = {dtype_dict[key]: key for key in dtype_dict}
     dtype_code_set = {reverse_dict[t.dtype] for t in seq}
     return dtype_dict[max(dtype_code_set)]
@@ -333,6 +350,10 @@ def maximum(a, b):
     return torch.max(array(a), array(b))
 
 
+def minimum(a, b):
+    return torch.min(array(a), array(b))
+
+
 def to_ndarray(x, to_ndim, axis=0):
     x = array(x)
     if x.dim() == to_ndim - 1:
@@ -830,3 +851,8 @@ def ravel_tril_indices(n, k=0, m=None):
 def sort(a, axis=-1):
     sorted_a, _ = torch.sort(a, dim=axis)
     return sorted_a
+
+
+def amin(a, axis=-1):
+    (values, _) = torch.min(a, dim=axis)
+    return values
