@@ -1,6 +1,7 @@
 """Torch based random backend."""
 
 import torch
+from torch.distributions.multivariate_normal import MultivariateNormal
 
 
 def choice(x, a):
@@ -28,14 +29,18 @@ def seed(*args, **kwargs):
 
 
 def normal(loc=0.0, scale=1.0, size=(1,)):
-    if not hasattr(size, '__iter__'):
+    if not hasattr(size, "__iter__"):
         size = (size,)
     return torch.normal(mean=loc, std=scale, size=size)
 
 
 def uniform(low=0.0, high=1.0, size=(1,)):
-    if not hasattr(size, '__iter__'):
+    if not hasattr(size, "__iter__"):
         size = (size,)
     if low >= high:
-        raise ValueError('Upper bound must be higher than lower bound')
+        raise ValueError("Upper bound must be higher than lower bound")
     return (high - low) * torch.rand(*size) + low
+
+
+def multivariate_normal(mean, cov, size=None):
+    return MultivariateNormal(mean, cov).sample(size)
