@@ -1,4 +1,7 @@
-"""Prepare and process graph-structured data."""
+"""Prepare and process graph-structured data.
+
+Lead author: Hadi Zaatiti.
+"""
 
 import logging
 import random
