@@ -36,7 +36,6 @@ class MatrixLieAlgebra(VectorSpace, abc.ABC):
         geomstats.errors.check_integer(dim, "dim")
         geomstats.errors.check_integer(n, "n")
         self.dim = dim
-        self.basis = None
         self.n = n
 
     bracket = Matrices.bracket
@@ -109,7 +108,7 @@ class MatrixLieAlgebra(VectorSpace, abc.ABC):
     def matrix_representation(self, basis_representation):
         """Compute the matrix representation for the given basis coefficients.
 
-        Sums the basis elements according to the coefficents given in
+        Sums the basis elements according to the coefficients given in
         basis_representation.
 
         Parameters
