@@ -37,7 +37,7 @@ class _SpecialOrthogonalMatrices(MatrixLieGroup, LevelSet):
         Integer representing the shape of the matrices: n x n.
     """
 
-    def __init__(self, n):
+    def __init__(self, n, **kwargs):
         matrices = Matrices(n, n)
         gln = GeneralLinear(n, positive_det=True)
         super(_SpecialOrthogonalMatrices, self).__init__(
@@ -49,9 +49,11 @@ class _SpecialOrthogonalMatrices(MatrixLieGroup, LevelSet):
             submersion=lambda x: matrices.mul(matrices.transpose(x), x),
             tangent_submersion=lambda v, x: 2
             * matrices.to_symmetric(matrices.mul(matrices.transpose(x), v)),
+            **kwargs,
         )
         self.bi_invariant_metric = BiInvariantMetric(group=self)
-        self.metric = self.bi_invariant_metric
+        if self._metric is None:
+            self._metric = self.bi_invariant_metric
 
     @classmethod
     def inverse(cls, point):
@@ -391,7 +393,7 @@ class _SpecialOrthogonalVectors(LieGroup):
         return -self.regularize(point)
 
     def random_point(self, n_samples=1, bound=1.0):
-        return gs.random.rand(n_samples, 3)
+        return gs.squeeze(gs.random.rand(n_samples, 3))
 
     def exp_from_identity(self, tangent_vec):
         """Compute the group exponential of the tangent vector at the identity.
@@ -1723,7 +1725,7 @@ class SpecialOrthogonal(
         default: 0
     """
 
-    def __new__(cls, n, point_type="matrix", epsilon=0.0):
+    def __new__(cls, n, point_type="matrix", epsilon=0.0, **kwargs):
         """Instantiate a special orthogonal group.
 
         Select the object to instantiate depending on the point_type.
@@ -1736,4 +1738,4 @@ class SpecialOrthogonal(
             raise NotImplementedError(
                 "SO(n) is only implemented in vector representation" " when n = 3."
             )
-        return _SpecialOrthogonalMatrices(n)
+        return _SpecialOrthogonalMatrices(n, **kwargs)
