@@ -32,7 +32,7 @@ class Stiefel(LevelSet):
         Number of basis vectors in the orthonormal frame.
     """
 
-    def __init__(self, n, p):
+    def __init__(self, n, p, **kwargs):
         geomstats.errors.check_integer(n, "n")
         geomstats.errors.check_integer(p, "p")
         if p > n:
@@ -40,6 +40,8 @@ class Stiefel(LevelSet):
 
         dim = int(p * n - (p * (p + 1) / 2))
         matrices = Matrices(n, p)
+        canonical_metric = StiefelCanonicalMetric(n, p)
+        kwargs.setdefault("metric", canonical_metric)
         super(Stiefel, self).__init__(
             dim=dim,
             embedding_space=matrices,
@@ -47,12 +49,11 @@ class Stiefel(LevelSet):
             value=gs.eye(p),
             tangent_submersion=lambda v, x: 2
             * matrices.to_symmetric(matrices.mul(matrices.transpose(x), v)),
-            metric=StiefelCanonicalMetric(n, p),
+            **kwargs
         )
-
+        self.canonical_metric = canonical_metric
         self.n = n
         self.p = p
-        self.canonical_metric = self.metric
 
     @staticmethod
     def to_grassmannian(point):
@@ -517,3 +518,30 @@ class StiefelCanonicalMetric(RiemannianMetric):
                 matrix_r[k, : len(column_r_j), j] = gs.array(column_r_j)
 
         return gs.matmul(point, matrix_r) - base_point
+
+    def injectivity_radius(self, base_point):
+        """Compute the radius of the injectivity domain.
+
+        This is is the supremum of radii r for which the exponential map is a
+        diffeomorphism from the open ball of radius r centered at the base point onto
+        its image.
+        In this case the exact injectivity radius is not known, and we use here a
+        lower bound given by [Rentmeesters2015]_.
+
+        Parameters
+        ----------
+        base_point : array-like, shape=[..., n, p]
+            Point on the manifold.
+
+        Returns
+        -------
+        radius : float
+            Injectivity radius.
+
+        References
+        ----------
+        .. [Rentmeesters2015] Rentmeesters, Quentin. “Algorithms for Data Fitting on
+        Some Common Homogeneous Spaces.” UCL - Université Catholique de Louvain, 2013.
+        https://dial.uclouvain.be/pr/boreal/object/boreal:132587.
+        """
+        return 0.89 * gs.pi
