@@ -1,4 +1,7 @@
-"""Frechet mean."""
+"""Frechet mean.
+
+Lead authors: Nicolas Guigui and Nina Miolane.
+"""
 
 import logging
 import math
@@ -8,6 +11,7 @@ from sklearn.base import BaseEstimator
 import geomstats.backend as gs
 import geomstats.errors as error
 import geomstats.vectorization
+from geomstats.geometry.hypersphere import Hypersphere
 
 EPSILON = 1e-4
 
@@ -85,7 +89,15 @@ def linear_mean(points, weights=None, point_type="vector"):
 
 
 def _default_gradient_descent(
-    points, metric, weights, max_iter, point_type, epsilon, initial_step_size, verbose
+    points,
+    metric,
+    weights,
+    max_iter,
+    point_type,
+    epsilon,
+    init_step_size,
+    verbose,
+    init_point=None,
 ):
     """Perform default gradient descent."""
     if point_type == "vector":
@@ -99,7 +111,7 @@ def _default_gradient_descent(
     if weights is None:
         weights = gs.ones((n_points,))
 
-    mean = points[0]
+    mean = points[0] if init_point is None else init_point
 
     if n_points == 1:
         return mean
@@ -111,7 +123,7 @@ def _default_gradient_descent(
     var = 0.0
 
     norm_old = gs.linalg.norm(points)
-    step = initial_step_size
+    step = init_step_size
 
     while iteration < max_iter:
         logs = metric.log(point=points, base_point=mean)
@@ -161,23 +173,38 @@ def _batch_gradient_descent(
     metric,
     weights=None,
     max_iter=32,
-    lr=1e-3,
+    init_step_size=1e-3,
     epsilon=5e-3,
     point_type="vector",
     verbose=False,
+    init_point=None,
 ):
     """Perform batch gradient descent."""
     if point_type == "vector":
         if points.ndim < 3:
             return _default_gradient_descent(
-                points, metric, weights, max_iter, point_type, epsilon, lr, verbose
+                points,
+                metric,
+                weights,
+                max_iter,
+                point_type,
+                epsilon,
+                init_step_size,
+                verbose,
             )
         einsum_str = "ni,nij->ij"
         ndim = 1
     else:
         if points.ndim < 4:
             return _default_gradient_descent(
-                points, metric, weights, max_iter, point_type, epsilon, lr, verbose
+                points,
+                metric,
+                weights,
+                max_iter,
+                point_type,
+                epsilon,
+                init_step_size,
+                verbose,
             )
         einsum_str = "nk,nkij->kij"
         ndim = 2
@@ -193,7 +220,7 @@ def _batch_gradient_descent(
         weights = gs.ones((n_points, n_batch))
 
     flat_shape = (n_batch * n_points,) + shape[-ndim:]
-    estimates = points[0]
+    estimates = points[0] if init_point is None else init_point
     points_flattened = gs.reshape(points, (n_points * n_batch,) + shape[-ndim:])
     convergence = math.inf
     iteration = 0
@@ -210,14 +237,14 @@ def _batch_gradient_descent(
 
         tangent_mean = gs.einsum(einsum_str, weights, tangent_grad) / n_points
 
-        next_estimates = metric.exp(lr * tangent_mean, estimates)
+        next_estimates = metric.exp(init_step_size * tangent_mean, estimates)
         convergence = gs.sum(metric.squared_norm(tangent_mean, estimates))
         estimates = next_estimates
 
         if convergence < convergence_old:
             convergence_old = convergence
         elif convergence > convergence_old:
-            lr = lr / 2.0
+            init_step_size = init_step_size / 2.0
 
     if iteration == max_iter:
         logging.warning(
@@ -228,7 +255,7 @@ def _batch_gradient_descent(
     if verbose:
         logging.info(
             "n_iter: {}, final dist: {},"
-            "final step size: {}".format(iteration, convergence, lr)
+            "final step size: {}".format(iteration, convergence, init_step_size)
         )
 
     return estimates
@@ -240,7 +267,7 @@ def _adaptive_gradient_descent(
     weights=None,
     max_iter=32,
     epsilon=1e-12,
-    initial_tau=1.0,
+    init_step_size=1.0,
     init_point=None,
     point_type="vector",
     verbose=False,
@@ -262,8 +289,10 @@ def _adaptive_gradient_descent(
         Weights associated to the points.
     max_iter : int, optional
         Maximum number of iterations for the gradient descent.
-    init_point : array-like, shape=[n_init, dimension], optional
+    init_point : array-like, shape=[{dim, [n, n]}]
         Initial point.
+        Optional, default : None. In this case the first sample of the input data is
+        used.
     epsilon : float, optional
         Tolerance for stopping the gradient descent.
 
@@ -294,7 +323,7 @@ def _adaptive_gradient_descent(
         weights = gs.ones((n_points,))
     sum_weights = gs.sum(weights)
 
-    tau = initial_tau
+    tau = init_step_size
     iteration = 0
 
     logs = metric.log(point=points, base_point=current_mean)
@@ -306,7 +335,7 @@ def _adaptive_gradient_descent(
         current_tangent_mean, base_point=current_mean
     )
 
-    while sq_norm_current_tangent_mean > epsilon ** 2 and iteration < max_iter:
+    while sq_norm_current_tangent_mean > epsilon**2 and iteration < max_iter:
         iteration += 1
 
         shooting_vector = tau * current_tangent_mean
@@ -348,6 +377,80 @@ def _adaptive_gradient_descent(
     return current_mean
 
 
+def _circle_mean(points):
+    """Determine the mean on a circle.
+
+    Data are expected in radians in the range [-pi, pi). The mean is returned
+    in the same range. If the mean is unique, this algorithm is guaranteed to
+    find it. It is not vulnerable to local minima of the Frechet function. If
+    the mean is not unique, the algorithm only returns one of the means. Which
+    mean is returned depends on numerical rounding errors.
+
+    Reference
+    ---------
+    ..[HH15]     Hotz, T. and S. F. Huckemann (2015), "Intrinsic means on the circle:
+                 Uniqueness, locus and asymptotics", Annals of the Institute of
+                 Statistical Mathematics 67 (1), 177–193.
+                 https://arxiv.org/abs/1108.2141
+    """
+    if points.ndim > 1:
+        points_ = Hypersphere.extrinsic_to_angle(points)
+    else:
+        points_ = gs.copy(points)
+    sample_size = points_.shape[0]
+    mean0 = gs.mean(points_)
+    var0 = gs.sum((points_ - mean0) ** 2)
+    sorted_points = gs.sort(points_)
+    means = _circle_variances(mean0, var0, sample_size, sorted_points)
+    return means[gs.argmin(means[:, 1]), 0]
+
+
+def _circle_variances(mean, var, n_samples, points):
+    """Compute the minimizer of the variance functional.
+
+    Parameters
+    ----------
+    mean : float
+        Mean angle.
+    var : float
+        Variance of the angles.
+    n_samples : int
+        Number of samples.
+    points : array-like, shape=[n,]
+        Data set of ordered angles.
+
+    References
+    ----------
+    ..[HH15]     Hotz, T. and S. F. Huckemann (2015), "Intrinsic means on the circle:
+                 Uniqueness, locus and asymptotics", Annals of the Institute of
+                 Statistical Mathematics 67 (1), 177–193.
+                 https://arxiv.org/abs/1108.2141
+    """
+    means = (mean + gs.linspace(0.0, 2 * gs.pi, n_samples + 1)[:-1]) % (2 * gs.pi)
+    means = gs.where(means >= gs.pi, means - 2 * gs.pi, means)
+    parts = gs.array([sum(points) / n_samples if means[0] < 0 else 0])
+    m_plus = means >= 0
+    left_sums = gs.cumsum(points)
+    right_sums = left_sums[-1] - left_sums
+    i = gs.arange(n_samples, dtype=right_sums.dtype)
+    j = i[1:]
+    parts2 = right_sums[:-1] / (n_samples - j)
+    first_term = parts2[:1]
+    parts2 = gs.where(m_plus[1:], left_sums[:-1] / j, parts2)
+    parts = gs.concatenate([parts, first_term, parts2[1:]])
+
+    # Formula (6) from [HH15]_
+    plus_vec = (4 * gs.pi * i / n_samples) * (gs.pi + parts - mean) - (
+        2 * gs.pi * i / n_samples
+    ) ** 2
+    minus_vec = (4 * gs.pi * (n_samples - i) / n_samples) * (gs.pi - parts + mean) - (
+        2 * gs.pi * (n_samples - i) / n_samples
+    ) ** 2
+    minus_vec = gs.where(m_plus, plus_vec, minus_vec)
+    means = gs.transpose(gs.vstack([means, var + minus_vec]))
+    return means
+
+
 class FrechetMean(BaseEstimator):
     r"""Empirical Frechet mean.
 
@@ -358,6 +461,9 @@ class FrechetMean(BaseEstimator):
     max_iter : int
         Maximum number of iterations for gradient descent.
         Optional, default: 32.
+    epsilon : float
+        Tolerance for stopping the gradient descent.
+        Optional, default : 1e-4
     point_type : str, {\'vector\', \'matrix\'}
         Point type.
         Optional, default: None.
@@ -368,6 +474,12 @@ class FrechetMean(BaseEstimator):
         method but for batches of equal length of samples. In this case,
         samples must be of shape [n_samples, n_batch, {dim, [n,n]}].
         Optional, default: \'default\'.
+    init_point : array-like, shape=[{dim, [n, n]}]
+        Initial point.
+        Optional, default : None. In this case the first sample of the input data is
+        used.
+    init_step_size : float
+        Initial step size or learning rate.
     verbose : bool
         Verbose option.
         Optional, default: False.
@@ -380,7 +492,8 @@ class FrechetMean(BaseEstimator):
         epsilon=EPSILON,
         point_type=None,
         method="default",
-        lr=1.0,
+        init_point=None,
+        init_step_size=1.0,
         verbose=False,
     ):
 
@@ -389,8 +502,9 @@ class FrechetMean(BaseEstimator):
         self.epsilon = epsilon
         self.point_type = point_type
         self.method = method
-        self.lr = lr
+        self.init_step_size = init_step_size
         self.verbose = verbose
+        self.init_point = init_point
         self.estimate_ = None
 
         if point_type is None:
@@ -426,6 +540,9 @@ class FrechetMean(BaseEstimator):
             or "MinkowskiMetric" in metric_str
         )
 
+        if "HypersphereMetric" in metric_str and self.metric.dim == 1:
+            mean = Hypersphere.angle_to_extrinsic(_circle_mean(X))
+
         error.check_parameter_accepted_values(
             self.method, "method", ["default", "adaptive", "batch"]
         )
@@ -439,32 +556,35 @@ class FrechetMean(BaseEstimator):
                 weights=weights,
                 metric=self.metric,
                 max_iter=self.max_iter,
-                initial_step_size=self.lr,
+                init_step_size=self.init_step_size,
                 point_type=self.point_type,
                 epsilon=self.epsilon,
                 verbose=self.verbose,
+                init_point=self.init_point,
             )
         elif self.method == "adaptive":
             mean = _adaptive_gradient_descent(
                 points=X,
-                weights=weights,
                 metric=self.metric,
+                weights=weights,
                 max_iter=self.max_iter,
-                point_type=self.point_type,
                 epsilon=self.epsilon,
+                init_step_size=self.init_step_size,
+                init_point=self.init_point,
+                point_type=self.point_type,
                 verbose=self.verbose,
-                initial_tau=self.lr,
             )
         elif self.method == "batch":
             mean = _batch_gradient_descent(
                 points=X,
-                weights=weights,
                 metric=self.metric,
-                lr=self.lr,
-                epsilon=self.epsilon,
+                weights=weights,
                 max_iter=self.max_iter,
+                init_step_size=self.init_step_size,
+                epsilon=self.epsilon,
                 point_type=self.point_type,
                 verbose=self.verbose,
+                init_point=self.init_point,
             )
 
         self.estimate_ = mean
